@@ -4,7 +4,7 @@
  * These macros extract bytes, words, longwords, floats, doubles, or
  * bitfields of arbitrary length and size from a message that contains
  * these items in either MSB-first or LSB-first byte order.
- * 
+ *
  * We enforce data sizes of integral types in the casts on these.
  * Both 32- and 64-bit systems with gcc are OK with this set.
  *
@@ -28,7 +28,7 @@
 #define getleu32(buf, off)	((uint32_t)(((uint16_t)getleu16((buf),(off)+2) << 16) | (uint16_t)getleu16((buf), (off))))
 #define getles64(buf, off)	((int64_t)(((uint64_t)getleu32(buf, (off)+4) << 32) | getleu32(buf, (off))))
 #define getleu64(buf, off)	((uint64_t)(((uint64_t)getleu32(buf, (off)+4) << 32) | getleu32(buf, (off))))
-extern float getlef32(const char *, int); 
+extern float getlef32(const char *, int);
 extern double getled64(const char *, int);
 
 #define putle16(buf, off, w) do {putbyte(buf, (off)+1, (uint)(w) >> 8); putbyte(buf, (off), (w));} while (0)
@@ -41,7 +41,7 @@ extern double getled64(const char *, int);
 #define getbeu32(buf, off)	((uint32_t)(((uint16_t)getbeu16(buf, (off)) << 16) | getbeu16(buf, (off)+2)))
 #define getbes64(buf, off)	((int64_t)(((uint64_t)getbeu32(buf, (off)) << 32) | getbeu32(buf, (off)+4)))
 #define getbeu64(buf, off)	((uint64_t)(((uint64_t)getbeu32(buf, (off)) << 32) | getbeu32(buf, (off)+4)))
-extern float getbef32(const char *, int); 
+extern float getbef32(const char *, int);
 extern double getbed64(const char *, int);
 
 #define putbe16(buf,off,w) do {putbyte(buf, (off), (w) >> 8); putbyte(buf, (off)+1, (w));} while (0)
@@ -50,7 +50,7 @@ extern double getbed64(const char *, int);
 extern void putbef32(char *, int, float);
 
 /* bitfield extraction */
-extern uint64_t ubits(char buf[], unsigned int, unsigned int, bool);
-extern int64_t sbits(char buf[], unsigned int, unsigned int, bool);
+extern uint64_t ubits(unsigned char buf[], unsigned int, unsigned int, bool);
+extern int64_t sbits(signed char buf[], unsigned int, unsigned int, bool);
 
 #endif /* _GPSD_BITS_H_ */
