@@ -1,5 +1,9 @@
+/* This file is Copyright (c)2010 by the GPSD project
+ * BSD terms apply: see the file COPYING in the distribution root for details.
+ */
 #include <sys/types.h>
 #include <err.h>
+#include <assert.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <stdarg.h>
@@ -56,11 +60,14 @@ int main(int argc, char **argv) {
 	while (1){
 		l = read(ifd, buf, BUFSIZ);
 		if (l > 0)
-			write(ofd, buf, l);
+		    assert(write(ofd, buf, l) > 0);
 		usleep(1000);
 		bzero(buf, BUFSIZ);
 		spinner( n++ );
 	}
+	/* NOTREACHED */
+	close(ifd);
+	close(ofd);
 	return 0;
 }
 
