@@ -9,7 +9,7 @@
  * 22-23, and 25-27 has not.
  * For the special IMO messages (types 6 and 8), only the following have been
  * tested against known-good decodings:
- *  - IMO236 met/hydro message: Type=8, DAC=1, FI=11 
+ *  - IMO236 met/hydro message: Type=8, DAC=1, FI=11
  *  - IMO289 met/hydro message: Type=8, DAC=1, FI=31
  *
  * This file is Copyright (c) 2010 by the GPSD project
@@ -26,7 +26,7 @@
  * Parse the data from the device
  */
 
-static void from_sixbit(char *bitvec, uint start, int count, char *to)
+static void from_sixbit(unsigned char *bitvec, uint start, int count, char *to)
 {
     /*@ +type @*/
 #ifdef S_SPLINT_S
@@ -68,9 +68,9 @@ bool ais_binary_decode(struct ais_t *ais,
     int i;
 
 #define BITS_PER_BYTE	8
-#define UBITS(s, l)	ubits((char *)bits, s, l, false)
-#define SBITS(s, l)	sbits((char *)bits, s, l, false)
-#define UCHARS(s, to)	from_sixbit((char *)bits, s, sizeof(to), to)
+#define UBITS(s, l)	ubits((unsigned char *)bits, s, l, false)
+#define SBITS(s, l)	sbits((signed char *)bits, s, l, false)
+#define UCHARS(s, to)	from_sixbit((unsigned char *)bits, s, sizeof(to), to)
     ais->type = UBITS(0, 6);
     ais->repeat = UBITS(6, 2);
     ais->mmsi = UBITS(8, 30);
@@ -328,7 +328,7 @@ bool ais_binary_decode(struct ais_t *ais,
 		break;
 	    case 30:	/* IMO289 - Text description - addressed */
 		ais->type6.dac1fid30.linkage   = UBITS(88, 10);
-		from_sixbit((char *)bits,
+		from_sixbit((unsigned char *)bits,
 			    98, bitlen-98,
 			    ais->type6.dac1fid30.text);
 		imo = true;
@@ -407,7 +407,7 @@ bool ais_binary_decode(struct ais_t *ais,
 		ais->type8.dac1fid11.wspeed		= UBITS(121, 7);
 		ais->type8.dac1fid11.wgust		= UBITS(128, 7);
 		ais->type8.dac1fid11.wdir		= UBITS(135, 9);
-		ais->type8.dac1fid11.wgustdir	= UBITS(144, 9); 
+		ais->type8.dac1fid11.wgustdir	= UBITS(144, 9);
 		ais->type8.dac1fid11.airtemp	= UBITS(153, 11);
 		ais->type8.dac1fid11.humidity	= UBITS(164, 7);
 		ais->type8.dac1fid11.dewpoint	= UBITS(171, 10);
@@ -536,7 +536,7 @@ bool ais_binary_decode(struct ais_t *ais,
 		break;
 	    case 29:        /* IMO289 - Text Description - broadcast */
 		ais->type8.dac1fid29.linkage   = UBITS(56, 10);
-		from_sixbit((char *)bits,
+		from_sixbit((unsigned char *)bits,
 			    66, bitlen-66,
 			    ais->type8.dac1fid29.text);
 		imo = true;
@@ -551,7 +551,7 @@ bool ais_binary_decode(struct ais_t *ais,
 		ais->type8.dac1fid31.wspeed		= UBITS(122, 7);
 		ais->type8.dac1fid31.wgust		= UBITS(129, 7);
 		ais->type8.dac1fid31.wdir		= UBITS(136, 9);
-		ais->type8.dac1fid31.wgustdir	= UBITS(145, 9); 
+		ais->type8.dac1fid31.wgustdir	= UBITS(145, 9);
 		ais->type8.dac1fid31.airtemp	= SBITS(154, 11);
 		ais->type8.dac1fid31.humidity	= UBITS(165, 7);
 		ais->type8.dac1fid31.dewpoint	= SBITS(172, 10);
@@ -629,7 +629,7 @@ bool ais_binary_decode(struct ais_t *ais,
 	ais->type12.dest_mmsi      = UBITS(40, 30);
 	ais->type12.retransmit     = (bool)UBITS(70, 1);
 	//ais->type12.spare        = UBITS(71, 1);
-	from_sixbit((char *)bits,
+	from_sixbit((unsigned char *)bits,
 		    72, bitlen-72,
 		    ais->type12.text);
 	break;
@@ -640,7 +640,7 @@ bool ais_binary_decode(struct ais_t *ais,
 	    return false;
 	}
 	//ais->type14.spare          = UBITS(38, 2);
-	from_sixbit((char *)bits,
+	from_sixbit((unsigned char *)bits,
 		    40, bitlen-40,
 		    ais->type14.text);
 	break;
@@ -783,10 +783,10 @@ bool ais_binary_decode(struct ais_t *ais,
 	    return false;
 	}
 	ais->type21.aid_type = UBITS(38, 5);
-	from_sixbit((char *)bits,
+	from_sixbit((unsigned char *)bits,
 		    43, 21, ais->type21.name);
 	if (strlen(ais->type21.name) == 20 && bitlen > 272)
-	    from_sixbit((char *)bits,
+	    from_sixbit((unsigned char *)bits,
 			272, (bitlen - 272)/6,
 			ais->type21.name+20);
 	ais->type21.accuracy     = UBITS(163, 1);
