@@ -1,4 +1,10 @@
 /* This code is generated.  Do not hand-hack it! */
+
+/*
+ * Also, beware that it is something of a CPU hog when called on every packet.
+ * Try to write guards so it is only called at higher log levels.
+ */
+
 #include <stdio.h>
 #include <string.h>
 
@@ -6,7 +12,7 @@
 
 const char *gps_maskdump(gps_mask_t set)
 {
-    static char buf[188];
+    static char buf[190];
     const struct {
 	gps_mask_t      mask;
 	const char      *name;
@@ -42,6 +48,15 @@ const char *gps_maskdump(gps_mask_t set)
 	{POLICY_SET,	"POLICY"},
 	{LOGMESSAGE_SET,	"LOGMESSAGE"},
 	{ERROR_SET,	"ERROR"},
+	{RAW_IS,	"RAW"},
+	{USED_IS,	"USED"},
+	{DRIVER_IS,	"DRIVER"},
+	{CLEAR_IS,	"CLEAR"},
+	{REPORT_IS,	"REPORT"},
+	{NODATA_IS,	"NODATA"},
+	{PPSTIME_IS,	"PPSTIME"},
+	{PERR_IS,	"PERR"},
+	{PASSTHROUGH_IS,	"PASSTHROUGH"},
     };
 
     memset(buf, '\0', sizeof(buf));
