@@ -20,7 +20,7 @@ advance what the type of each attribute value will be and where the
 parsed value will be stored. The template structures may supply
 default values to be used when an expected attribute is omitted.
 
-   The preceding paragraph told one fib.  A single attribute may 
+   The preceding paragraph told one fib.  A single attribute may
 actually have a span of multiple specifications with different
 syntactically distinguishable types (e.g. string vs. real vs. integer
 vs boolean, but not signed integer vs. unsigned integer or strong vs. map).
@@ -40,7 +40,7 @@ stored as doubles.
 defending on whether the array subtype is declared as object or
 structobject.
 
-   Object arrays take one base address per object subfield, and are 
+   Object arrays take one base address per object subfield, and are
 mapped into parallel C arrays (one per subfield).  Strings are not
 supported in this kind of array, as they don't have a "natural" size
 to use as an offset multiplier.
@@ -193,14 +193,14 @@ static int json_internal_read_object(const char *cp,
 	    if (lptr != NULL)
 		switch (cursor->type) {
 		case t_integer:
-		    *((int *)lptr) = cursor->dflt.integer;
+		    memcpy(lptr, &cursor->dflt.integer, sizeof(int));
 		    break;
 		case t_uinteger:
-		    *((unsigned int *)lptr) = cursor->dflt.uinteger;
+		    memcpy(lptr, &cursor->dflt.uinteger, sizeof(unsigned int));
 		    break;
 		case t_time:
 		case t_real:
-		    *((double *)lptr) = cursor->dflt.real;
+		    memcpy(lptr, &cursor->dflt.real, sizeof(double));
 		    break;
 		case t_string:
 		    if (parent != NULL
@@ -210,7 +210,7 @@ static int json_internal_read_object(const char *cp,
 		    lptr[0] = '\0';
 		    break;
 		case t_boolean:
-		    *((bool *) lptr) = cursor->dflt.boolean;
+		    memcpy(lptr, &cursor->dflt.boolean, sizeof(bool));
 		    break;
 		case t_character:
 		    lptr[0] = cursor->dflt.character;
@@ -411,7 +411,7 @@ static int json_internal_read_object(const char *cp,
 	    }
 	    if (value_quoted
 		&& (cursor->type != t_string && cursor->type != t_character
-		    && cursor->type != t_check && cursor->type != t_time 
+		    && cursor->type != t_check && cursor->type != t_time
 		    && cursor->map == 0)) {
 		json_debug_trace((1,
 				  "Saw quoted value when expecting non-string.\n"));
@@ -439,16 +439,28 @@ static int json_internal_read_object(const char *cp,
 	    if (lptr != NULL)
 		switch (cursor->type) {
 		case t_integer:
-		    *((int *)lptr) = atoi(valbuf);
+		    {
+			int tmp = atoi(valbuf);
+			memcpy(lptr, &tmp, sizeof(int));
+		    }
 		    break;
 		case t_uinteger:
-		    *((unsigned int *)lptr) = (unsigned)atoi(valbuf);
+		    {
+			unsigned int tmp = (unsigned int)atoi(valbuf);
+			memcpy(lptr, &tmp, sizeof(unsigned int));
+		    }
 		    break;
 		case t_time:
-		    *((double *)lptr) = iso8601_to_unix(valbuf);
+		    {
+			double tmp = iso8601_to_unix(valbuf);
+			memcpy(lptr, &tmp, sizeof(double));
+		    }
 		    break;
 		case t_real:
-		    *((double *)lptr) = safe_atof(valbuf);
+		    {
+			double tmp = safe_atof(valbuf);
+			memcpy(lptr, &tmp, sizeof(double));
+		    }
 		    break;
 		case t_string:
 		    if (parent != NULL
@@ -458,7 +470,10 @@ static int json_internal_read_object(const char *cp,
 		    (void)strlcpy(lptr, valbuf, cursor->len);
 		    break;
 		case t_boolean:
-		    *((bool *) lptr) = (strcmp(valbuf, "true") == 0);
+		    {
+			bool tmp = (strcmp(valbuf, "true") == 0);
+			memcpy(lptr, &tmp, sizeof(bool));
+		    }
 		    break;
 		case t_character:
 		    if (strlen(valbuf) > 1)
