@@ -4,9 +4,10 @@
  * This file is Copyright (c) 2010 by the GPSD project
  * BSD terms apply: see the file COPYING in the distribution root for details.
  */
+#include <assert.h>
+
 #include "gpsd.h"
 #include "gpsmon.h"
-#include "assert.h"
 
 #ifdef TNT_ENABLE
 extern const struct gps_type_t trueNorth;
