@@ -205,6 +205,7 @@ static bool ntpshm_free(struct gps_context_t * context, int segment)
 	return false;
 
     context->shmTimeInuse[segment] = false;
+    segment = -1;
     return true;
 }
 
@@ -582,9 +583,8 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 
     /*  Activates PPS support for RS-232 or USB devices only. */
     if (!(session->sourcetype == source_rs232 || session->sourcetype == source_usb)) {
-	gpsd_report(LOG_PROG, "PPS thread deactivationde. Not RS-232 or USB device.\n");
+	gpsd_report(LOG_PROG, "PPS thread deactivation. Not RS-232 or USB device.\n");
 	(void)ntpshm_free(session->context, session->shmTimeP);
-	session->shmTimeP = -1;
 	return NULL;
     }
 
@@ -632,7 +632,6 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
     while (!gpsd_ppsmonitor_stop) {
 	bool ok = false;
 	char *log = NULL;
-	char *log1 = NULL;
 
 #if defined(TIOCMIWAIT)
 #define PPS_LINE_TIOC (TIOCM_CD|TIOCM_CAR|TIOCM_RI|TIOCM_CTS)
@@ -856,6 +855,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 #endif /* TIOCMIWAIT */
 
 	if (ok) {
+	    char *log1 = NULL;
 	    gpsd_report(LOG_RAW, "PPS edge accepted %.100s", log);
 	    /* chrony expects tv-sec since Jan 1970 */
 	    /* FIXME!! offset is double of the error from local time */
@@ -952,13 +952,10 @@ void ntpd_link_deactivate(struct gps_device_t *session)
 /* release ntpshm storage for a session */
 {
     (void)ntpshm_free(session->context, session->shmindex);
-    session->shmindex = -1;
 #if defined(PPS_ENABLE)
-    if (session->context->shmTimePPS &&
-	    (session->sourcetype == source_rs232 || session->sourcetype == source_usb)) {
+    if (session->context->shmTimePPS && (session->shmTimeP != -1)) {
 	pps_thread_deactivate(session);
 	(void)ntpshm_free(session->context, session->shmTimeP);
-	session->shmTimeP = -1;
     }
 #endif	/* PPS_ENABLE */
 }
